#

""" Module main entry point
"""

import sys

from . import cli

if __name__ == '__main__':
    sys.exit(cli.main())

# EOF
